@@ -1,7 +1,7 @@
 
 from django.db import models
 from django.urls import reverse_lazy
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 
 class FlatPage(models.Model):
