@@ -14,4 +14,7 @@ def flatpage(request, url):
 
     template_name = obj.template_name or 'flatpages/default.html'
 
-    return render(request, template_name, {'flatpage': obj})
+    return render(request, template_name, {
+        'flatpage': obj,
+        'breadcrumbs': [{'name': obj.title}]
+    })
